@@ -4,16 +4,17 @@ from typing_extensions import TypedDict
 from .event import Event
 
 
-DataType = TypedDict('DataType', {'message': Optional[str]})
+DataType = TypedDict("DataType", {"message": Optional[str]})
 
 
 class TestEvent(Event):
     """Just a test event."""
-    __module__ = 'pyobs.events'
+
+    __module__ = "pyobs.events"
 
     def __init__(self, message: Optional[str] = None, **kwargs: Any):
         Event.__init__(self)
-        self.data['message'] = message
+        self.data["message"] = message
 
 
-__all__ = ['TestEvent']
+__all__ = ["TestEvent"]
