@@ -5,13 +5,14 @@ from pyobs.images import Image
 
 class FocusSeries:
     """Base class for focus series helper classes."""
-    __module__ = 'pyobs.utils.focusseries'
 
-    def reset(self):
+    __module__ = "pyobs.utils.focusseries"
+
+    def reset(self) -> None:
         """Reset focus series."""
         raise NotImplementedError
 
-    def analyse_image(self, image: Image):
+    def analyse_image(self, image: Image) -> None:
         """Analyse given image.
 
         Args:
@@ -28,4 +29,4 @@ class FocusSeries:
         raise NotImplementedError
 
 
-__all__ = ['FocusSeries']
+__all__ = ["FocusSeries"]
